@@ -5,10 +5,8 @@ PDL::Constants -- basic compile time constants for PDL
 =head1 DESCRIPTION
 
 This module is used to define compile time constant
-values for PDL.  It uses the constant module for
-simplicity and availability.  We'll need to sort
-out exactly which constants make sense but PI and
-E seem to be fundamental.
+values for PDL.  It uses Perl's L<constant> pragma for
+simplicity and availability.
 
 =head1 SYNOPSIS
 
@@ -19,15 +17,15 @@ E seem to be fundamental.
 =cut
 
 package PDL::Constants;
-our $VERSION = 0.02;
+our $VERSION = "0.02";
+$VERSION = eval $VERSION;
 
 require Exporter;
 @ISA = qw(Exporter);
-@EXPORT_OK = qw(PI E I J);  # symbols to export
+@EXPORT_OK = qw(PI DEGRAD E I J);  # symbols to export
 
 use PDL::Lite;
-use PDL::Complex qw(i);
-                           
+
 =head2 PI
 
 The ratio of a circle's circumference to its diameter
@@ -36,6 +34,14 @@ The ratio of a circle's circumference to its diameter
 
 use constant PI    => 4 * atan2(1, 1);
 
+=head2 DEGRAD
+
+The number of degrees of arc per radian (180/PI)
+
+=cut
+
+use constant DEGRAD => 180/PI;
+
 =head2 E
 
 The base of the natural logarithms or Euler's number
@@ -50,7 +56,10 @@ The imaginary unit, C< I*I == -1 >
 
 =cut
 
-use constant I     => i;
+sub I () {
+  require PDL::Complex;
+  goto &PDL::Complex::i;
+}
 
 =head2 J
 
@@ -58,7 +67,10 @@ The imaginary unit for engineers, C< J*J == -1 >
 
 =cut
 
-use constant J     => i;
+sub J () {
+  require PDL::Complex;
+  goto &PDL::Complex::i;
+}
 
 =head1 COPYRIGHT & LICENSE
 
